==> ansible-9.3.0.tgz: lib/python3.10/site-packages/ansible_collections/cisco/meraki/plugins/modules/networks_switch_routing_ospf_info.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: networks_switch_routing_ospf_info
short_description: Information module for networks _switch _routing _ospf
description:
- Get all networks _switch _routing _ospf.
- Return layer 3 OSPF routing configuration.
version_added: '2.16.0'
extends_documentation_fragment:
  - cisco.meraki.module_info
author: Francisco Munoz (@fmunoz)
options:
  headers:
    description: Additional headers.
    type: dict
  networkId:
    description:
    - NetworkId path parameter. Network ID.
    type: str
requirements:
- meraki >= 2.4.9
- python >= 3.5
seealso:
- name: Cisco Meraki documentation for switch getNetworkSwitchRoutingOspf
  description: Complete reference of the getNetworkSwitchRoutingOspf API.
  link: https://developer.cisco.com/meraki/api-v1/#!get-network-switch-routing-ospf
notes:
  - SDK Method used are
    switch.Switch.get_network_switch_routing_ospf,

  - Paths used are
    get /networks/{networkId}/switch/routing/ospf,
"""

EXAMPLES = r"""
- name: Get all networks _switch _routing _ospf
  cisco.meraki.networks_switch_routing_ospf_info:
    meraki_api_key: "{{meraki_api_key}}"
    meraki_base_url: "{{meraki_base_url}}"
    meraki_single_request_timeout: "{{meraki_single_request_timeout}}"
    meraki_certificate_path: "{{meraki_certificate_path}}"
    meraki_requests_proxy: "{{meraki_requests_proxy}}"
    meraki_wait_on_rate_limit: "{{meraki_wait_on_rate_limit}}"
    meraki_nginx_429_retry_wait_time: "{{meraki_nginx_429_retry_wait_time}}"
    meraki_action_batch_retry_wait_time: "{{meraki_action_batch_retry_wait_time}}"
    meraki_retry_4xx_error: "{{meraki_retry_4xx_error}}"
    meraki_retry_4xx_error_wait_time: "{{meraki_retry_4xx_error_wait_time}}"
    meraki_maximum_retries: "{{meraki_maximum_retries}}"
    meraki_output_log: "{{meraki_output_log}}"
    meraki_log_file_prefix: "{{meraki_log_file_prefix}}"
    meraki_log_path: "{{meraki_log_path}}"
    meraki_print_console: "{{meraki_print_console}}"
    meraki_suppress_logging: "{{meraki_suppress_logging}}"
    meraki_simulate: "{{meraki_simulate}}"
    meraki_be_geo_id: "{{meraki_be_geo_id}}"
    meraki_use_iterator_for_get_pages: "{{meraki_use_iterator_for_get_pages}}"
    meraki_inherit_logging_config: "{{meraki_inherit_logging_config}}"
    networkId: string
  register: result

"""
RETURN = r"""
meraki_response:
  description: A dictionary or list with the response returned by the Cisco Meraki Python SDK
  returned: always
  type: dict
  sample:
  - {}
"""

==> ansible-10.6.0.tgz: lib/python3.11/site-packages/ansible_collections/cisco/meraki/plugins/modules/networks_switch_routing_ospf_info.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: networks_switch_routing_ospf_info
short_description: Information module for networks _switch _routing _ospf
description:
- Get all networks _switch _routing _ospf.
- Return layer 3 OSPF routing configuration.
version_added: '2.16.0'
extends_documentation_fragment:
  - cisco.meraki.module_info
author: Francisco Munoz (@fmunoz)
options:
  headers:
    description: Additional headers.
    type: dict
  networkId:
    description:
    - NetworkId path parameter. Network ID.
    type: str
requirements:
- meraki >= 2.4.9
- python >= 3.5
seealso:
- name: Cisco Meraki documentation for switch getNetworkSwitchRoutingOspf
  description: Complete reference of the getNetworkSwitchRoutingOspf API.
  link: https://developer.cisco.com/meraki/api-v1/#!get-network-switch-routing-ospf
notes:
  - SDK Method used are
    switch.Switch.get_network_switch_routing_ospf,

  - Paths used are
    get /networks/{networkId}/switch/routing/ospf,
"""

EXAMPLES = r"""
- name: Get all networks _switch _routing _ospf
  cisco.meraki.networks_switch_routing_ospf_info:
    meraki_api_key: "{{meraki_api_key}}"
    meraki_base_url: "{{meraki_base_url}}"
    meraki_single_request_timeout: "{{meraki_single_request_timeout}}"
    meraki_certificate_path: "{{meraki_certificate_path}}"
    meraki_requests_proxy: "{{meraki_requests_proxy}}"
    meraki_wait_on_rate_limit: "{{meraki_wait_on_rate_limit}}"
    meraki_nginx_429_retry_wait_time: "{{meraki_nginx_429_retry_wait_time}}"
    meraki_action_batch_retry_wait_time: "{{meraki_action_batch_retry_wait_time}}"
    meraki_retry_4xx_error: "{{meraki_retry_4xx_error}}"
    meraki_retry_4xx_error_wait_time: "{{meraki_retry_4xx_error_wait_time}}"
    meraki_maximum_retries: "{{meraki_maximum_retries}}"
    meraki_output_log: "{{meraki_output_log}}"
    meraki_log_file_prefix: "{{meraki_log_file_prefix}}"
    meraki_log_path: "{{meraki_log_path}}"
    meraki_print_console: "{{meraki_print_console}}"
    meraki_suppress_logging: "{{meraki_suppress_logging}}"
    meraki_simulate: "{{meraki_simulate}}"
    meraki_be_geo_id: "{{meraki_be_geo_id}}"
    meraki_use_iterator_for_get_pages: "{{meraki_use_iterator_for_get_pages}}"
    meraki_inherit_logging_config: "{{meraki_inherit_logging_config}}"
    networkId: string
  register: result

"""
RETURN = r"""
meraki_response:
  description: A dictionary or list with the response returned by the Cisco Meraki Python SDK
  returned: always
  type: dict
  sample: >
    {
      "areas": [
        {
          "areaId": "string",
          "areaName": "string",
          "areaType": "string"
        }
      ],
      "deadTimerInSeconds": 0,
      "enabled": true,
      "helloTimerInSeconds": 0,
      "md5AuthenticationEnabled": true,
      "md5AuthenticationKey": {
        "id": 0,
        "passphrase": "string"
      },
      "v3": {
        "areas": [
          {
            "areaId": "string",
            "areaName": "string",
            "areaType": "string"
          }
        ],
        "deadTimerInSeconds": 0,
        "enabled": true,
        "helloTimerInSeconds": 0
      }
    }
"""
